## 3.0.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 3.0.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 3.0.0.7 (2023-11-24)

Third-party stubs: remove unused `type: ignore`s (#11063)

## 3.0.0.6 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 3.0.0.5 (2023-03-27)

Add defaults for third-party stubs E-H (#9954)

## 3.0.0.4 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.0.0.3 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 3.0.0.2 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 3.0.0.1 (2022-12-27)

Fully annotate ExifRead (#9403)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 3.0.0.0 (2022-12-23)

Initial ExifRead stubs (#9401)

